@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: constants.c,v 1.11 2005/06/23 01:45:55 mcr Exp $
+ * RCSID $Id: constants.c,v 1.11.2.1 2006/11/02 18:36:29 paul Exp $
  */
 
 /*
@@ -916,8 +916,8 @@ enum_names ppk_names = { PPK_PSK, PPK_PIN, ppk_name, NULL };
 const char *const natt_type_bitnames[] = {
   "draft-ietf-ipsec-nat-t-ike-00/01",    /* 0 */
   "draft-ietf-ipsec-nat-t-ike-02/03",
-  "RFC 3947 (NAT-Traversal)",
-  "3",                                   /* 3 */
+  "draft-ietf-ipsec-nat-t-ike (MacOS X)", 
+  "RFC 3947 (NAT-Traversal)",		/* 3 */
   "4",   "5",   "6",   "7", 
   "8",   "9",   "10",  "11",
   "12",  "13",  "14",  "15",
