@@ -18,10 +18,12 @@
  * Split out from ipsec_init.c version 1.70.
  */
 
-char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.39.2.2 2006/02/13 18:48:12 paul Exp $";
+char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.39.2.4 2006/11/15 22:21:39 paul Exp $";
 
 
+#ifndef AUTOCONF_INCLUDED
 #include <linux/config.h>
+#endif
 #include <linux/version.h>
 #define __NO_VERSION__
 #include <linux/module.h>
@@ -609,6 +611,13 @@ ipsec_version_get_info(char *buffer,
 	return len;
 }
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+unsigned int natt_available = 1;
+#else
+unsigned int natt_available = 0;
+#endif
+module_param(natt_available, int, 0444);
+
 IPSEC_PROCFS_DEBUG_NO_STATIC
 int
 ipsec_natt_get_info(char *buffer,
@@ -1006,6 +1015,14 @@ ipsec_proc_cleanup()
 
 /*
  * $Log: ipsec_proc.c,v $
+ * Revision 1.39.2.4  2006/11/15 22:21:39  paul
+ * backport of creating a /sys/ file to test for nat-t capability in kernel.
+ *
+ * Revision 1.39.2.3  2006/10/06 21:39:26  paul
+ * Fix for 2.6.18+ only include linux/config.h if AUTOCONF_INCLUDED is not
+ * set. This is defined through autoconf.h which is included through the
+ * linux kernel build macros.
+ *
  * Revision 1.39.2.2  2006/02/13 18:48:12  paul
  * Fix by  Ankit Desai <ankit@elitecore.com> for module unloading.
  *
