@@ -15,11 +15,13 @@
  * for more details.
  */
 
-char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.20.2.6 2006/07/07 22:09:49 paul Exp $";
+char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.20.2.9 2007/07/06 17:18:43 paul Exp $";
 
 #define __NO_VERSION__
 #include <linux/module.h>
-#include <linux/config.h>	/* for CONFIG_IP_FORWARD */
+#ifndef AUTOCONF_INCLUDED
+#include <linux/config.h>
+#endif	/* for CONFIG_IP_FORWARD */
 #include <linux/version.h>
 #include <linux/kernel.h> /* printk() */
 
@@ -537,6 +539,7 @@ ipsec_xmit_encap_once(struct ipsec_xmit_state *ixs)
 		ixt_a=ixs->ipsp->ips_alg_auth;
 		if (ixt_a) {
 			tailroom += AHHMAC_HASHLEN;
+			authlen = AHHMAC_HASHLEN;
 		} else 
 		switch(ixs->ipsp->ips_authalg) {
 #ifdef CONFIG_KLIPS_AUTH_HMAC_MD5
@@ -644,10 +647,11 @@ ipsec_xmit_encap_once(struct ipsec_xmit_state *ixs)
 		
 		dat[len - authlen - 1] = ixs->iph->protocol;
 		ixs->iph->protocol = IPPROTO_ESP;
-		
+#ifdef CONFIG_KLIPS_DEBUG
 		if(debug_tunnel & DB_TN_ENCAP) {
 		        dmp("pre-encrypt", dat, len);
 		}
+#endif
 
 		/*
 		 * Do all operations here:
@@ -1694,10 +1698,11 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 			    "head,tailroom: %d,%d after allocation\n",
 			    skb_headroom(ixs->skb), skb_tailroom(ixs->skb));
 	}
-		
+#ifdef CONFIG_KLIPS_DEBUG		
 	if(debug_tunnel & DB_TN_ENCAP) {
 		ipsec_print_ip(ixs->iph);
 	}
+#endif
 
 	/*
 	 * Apply grouped transforms to packet
@@ -1706,10 +1711,11 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 		enum ipsec_xmit_value encap_stat = IPSEC_XMIT_OK;
 
 		encap_stat = ipsec_xmit_encap_once(ixs);
-
+#ifdef CONFIG_KLIPS_DEBUG
 		if(debug_tunnel & DB_TN_ENCAP) {
 			ipsec_print_ip(ixs->iph);
 		}
+#endif
 
 		if(encap_stat != IPSEC_XMIT_OK) {
 			KLIPS_PRINT(debug_tunnel & DB_TN_XMIT,
@@ -1732,6 +1738,18 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 
 /*
  * $Log: ipsec_xmit.c,v $
+ * Revision 1.20.2.9  2007/07/06 17:18:43  paul
+ * Fix for authentication field on sent packets has size equals to zero when
+ * using custom auth algorithms. This is bug #811. Patch by "iamscared".
+ *
+ * Revision 1.20.2.8  2006/10/06 21:39:26  paul
+ * Fix for 2.6.18+ only include linux/config.h if AUTOCONF_INCLUDED is not
+ * set. This is defined through autoconf.h which is included through the
+ * linux kernel build macros.
+ *
+ * Revision 1.20.2.7  2006/08/24 03:02:01  paul
+ * Compile fixes for when CONFIG_KLIPS_DEBUG is not set. (bug #642)
+ *
  * Revision 1.20.2.6  2006/07/07 22:09:49  paul
  * From: Bart Trojanowski <bart@xelerance.com>
  * Removing a left over '#else' that split another '#if/#endif' block in two.
