@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: nat_traversal.c,v 1.26.2.7 2006/04/04 22:05:07 ken Exp $
+ * RCSID $Id: nat_traversal.c,v 1.26.2.10 2007/07/09 23:08:47 paul Exp $
  */
 
 #ifdef NAT_TRAVERSAL
@@ -676,7 +676,9 @@ static void nat_traversal_ka_event_state (struct state *st, void *data)
 		st_newest = state_with_serialno(c->newest_isakmp_sa);
 		if ((st_newest)
 		    && ((st_newest->st_state==STATE_MAIN_R3)
-			|| (st_newest->st_state==STATE_MAIN_I4))
+                       || (st_newest->st_state==STATE_MAIN_I4)
+                       || (st_newest->st_state == STATE_AGGR_R2)
+                       || (st_newest->st_state == STATE_AGGR_I2))
 		    && (st_newest->hidden_variables.st_nat_traversal & NAT_T_DETECTED)
 		    && ((st_newest->hidden_variables.st_nat_traversal & LELEM(NAT_TRAVERSAL_NAT_BHND_ME))
 			|| (_force_ka)))
@@ -689,6 +691,41 @@ static void nat_traversal_ka_event_state (struct state *st, void *data)
 	    reset_cur_state();
 	    (*_kap_st)++;
 	}
+       if ( ((st->st_state == STATE_QUICK_R2)
+             || (st->st_state == STATE_QUICK_I2))
+            && (st->hidden_variables.st_nat_traversal & NAT_T_DETECTED)
+            && ((st->hidden_variables.st_nat_traversal & LELEM(NAT_TRAVERSAL_NAT_BHND_ME))
+                || (_force_ka)))
+       {
+           /**
+            * - IPSEC SA established
+            * - NAT-Traversal detected
+            * - NAT-KeepAlive needed (we are NATed)
+            */
+           if (c->newest_ipsec_sa != st->st_serialno) {
+               /** 
+                * if newest is also valid, ignore this one, we will only use
+                * newest. 
+                */
+               struct state *st_newest;
+               st_newest = state_with_serialno(c->newest_ipsec_sa);
+               if ((st_newest)
+                   && ((st_newest->st_state==STATE_QUICK_R2)
+                       || (st_newest->st_state == STATE_QUICK_I2))
+                   && (st_newest->hidden_variables.st_nat_traversal & NAT_T_DETECTED)
+                   && ((st_newest->hidden_variables.st_nat_traversal & LELEM(NAT_TRAVERSAL_NAT_BHND_ME))
+                       || (_force_ka)))
+               {
+                   return;
+               }
+           }
+           set_cur_state(st);
+           nat_traversal_send_ka(st);
+           reset_cur_state();
+           (*_kap_st)++;
+       }
+       
+
 }
 
 void nat_traversal_ka_event (void)
@@ -761,7 +798,7 @@ static int nat_traversal_new_mapping(const ip_address *src, u_int16_t sport,
 		return 0;
 	}
 
-	DBG_log("NAT-T: new mapping %s:%d/%d)", srca, sport, dport);
+	DBG(DBG_CONTROLMORE, DBG_log("NAT-T: new mapping %s:%d/%d)", srca, sport, dport));
 
 	nfo.addr = *src;
 	nfo.sport = sport;
@@ -805,10 +842,11 @@ void nat_traversal_change_port_lookup(struct msg_digest *md, struct state *st)
 
 	/**
 	 * If we're initiator and NAT-T (with port floating) is detected, we
-	 * need to change port (MAIN_I3 or QUICK_I1)
+	 * need to change port (MAIN_I3, QUICK_I1 or AGGR_I2)
 	 */
 	if (((st->st_state == STATE_MAIN_I3)
-	     || (st->st_state == STATE_QUICK_I1))
+	     || (st->st_state == STATE_QUICK_I1)
+	     || (st->st_state == STATE_AGGR_I2))
 	    && (st->hidden_variables.st_nat_traversal & NAT_T_WITH_PORT_FLOATING)
 	    && (st->hidden_variables.st_nat_traversal & NAT_T_DETECTED)
 	    && (st->st_localport != NAT_T_IKE_FLOAT_PORT))
@@ -938,6 +976,16 @@ void process_pfkey_nat_t_new_mapping(
 
 /*
  * $Log: nat_traversal.c,v $
+ * Revision 1.26.2.10  2007/07/09 23:08:47  paul
+ * Ensured two debug lines only appear when plutodebug=control is specified.
+ *
+ * Revision 1.26.2.9  2007/01/22 22:42:43  paul
+ * Second part of Delta Yeh's patch of nat_traversal with aggressive mode,
+ * posted in bug #491.
+ *
+ * Revision 1.26.2.8  2007/01/22 20:46:59  paul
+ * Fix for Aggressive Mode and NAT-T port floating, based on RedHat patch.
+ *
  * Revision 1.26.2.7  2006/04/04 22:05:07  ken
  * Fix NAT Detection when initiator is behind NAT
  *
@@ -1020,6 +1068,6 @@ void process_pfkey_nat_t_new_mapping(
  * 	added log info.
  *
  *
- * $Id: nat_traversal.c,v 1.26.2.7 2006/04/04 22:05:07 ken Exp $
+ * $Id: nat_traversal.c,v 1.26.2.10 2007/07/09 23:08:47 paul Exp $
  *
  */
