@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: spdb_struct.c,v 1.13.2.10 2005/11/18 06:21:01 ken Exp $
+ * RCSID $Id: spdb_struct.c,v 1.13.2.15 2007/05/13 21:56:48 paul Exp $
  */
 
 #include <stdio.h>
@@ -947,7 +947,7 @@ parse_isakmp_sa_body(
 		    ta.group = lookup_group(val);
 		    if (ta.group == NULL)
 		    {
-			ugh = "only OAKLEY_GROUP_MODP1024 and OAKLEY_GROUP_MODP1536 supported";
+			ugh = builddiag("Diffie-Hellman group %d is not a supported modp group" , val);
 			break;
 		    }
 		    break;
@@ -1230,7 +1230,7 @@ init_am_st_oakley(struct state *st, lset_t policy)
     passert(prop->trans_cnt == 1);
     trans = &prop->trans[0];
 
-    passert(trans->attr_cnt == 4);
+    passert(trans->attr_cnt == 4 || trans->attr_cnt == 5);
     enc  = &trans->attrs[0];
     hash = &trans->attrs[1];
     auth = &trans->attrs[2];
@@ -1246,7 +1246,14 @@ init_am_st_oakley(struct state *st, lset_t policy)
     ta.encrypt = enc->val;             /* OAKLEY_ENCRYPTION_ALGORITHM */
     ta.encrypter = crypto_get_encrypter(ta.encrypt);
     passert(ta.encrypter != NULL);
-    ta.enckeylen = ta.encrypter->keydeflen;
+
+    if(trans->attr_cnt == 5) {
+	struct db_attr *enc_keylen;
+	enc_keylen = &trans->attrs[4];
+	ta.enckeylen = enc_keylen->val;
+    } else {
+	ta.enckeylen = ta.encrypter->keydeflen;
+    }
 
     passert(hash->type == OAKLEY_HASH_ALGORITHM);
     ta.hash = hash->val;               /* OAKLEY_HASH_ALGORITHM */
@@ -2123,22 +2130,22 @@ parse_ipsec_sa_body(
 		    loglog(RC_LOG_SERIOUS
 			   , "AH and ESP transforms disagree about encapsulation; TUNNEL presumed");
 		}
+#ifdef KERNEL_ALG
+		/* 
+		 * ML: at last check for allowed transforms in alg_info_esp 
+		 *     (ALG_INFO_F_STRICT flag)
+		 *
+		 */
+		if (c->alg_info_esp!=NULL
+		    && !kernel_alg_esp_ok_final(esp_attrs.transid, esp_attrs.key_len,
+						esp_attrs.auth, c->alg_info_esp))
+			continue;
+#endif
 
 		break;	/* we seem to be happy */
 	    }
 	    if (tn == esp_proposal.isap_notrans)
 		continue;	/* we didn't find a nice one */
-#ifdef KERNEL_ALG
-	    /* 
-	     * ML: at last check for allowed transforms in alg_info_esp 
-	     *     (ALG_INFO_F_STRICT flag)
-	     *
-	     */
-	    if (c->alg_info_esp!=NULL
-		&& !kernel_alg_esp_ok_final(esp_attrs.transid, esp_attrs.key_len,
-					    esp_attrs.auth, c->alg_info_esp))
-		    continue;
-#endif
 	    esp_attrs.spi = esp_spi;
 	    inner_proto = IPPROTO_ESP;
 	    if (esp_attrs.encapsulation == ENCAPSULATION_MODE_TUNNEL)
