@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: whack.c,v 1.144.4.3 2005/07/26 02:11:23 ken Exp $
+ * RCSID $Id: whack.c,v 1.144.4.11 2006/10/27 20:05:09 paul Exp $
  */
 
 #include <stdio.h>
@@ -64,6 +64,8 @@ help(void)
 	    " \\\n   "
 	    " (--host <ip-address> | --id <identity> | --cert <path>)"
 	    " [--ca <distinguished name>]"
+	    " [--sendcert <yes|forced|ifasked|no>]"
+	    " [--certtype number]"
 	    " [--ikeport <port-number>]"
 	    " \\\n   "
 	    " [--nexthop <ip-address>]"
@@ -72,6 +74,15 @@ help(void)
 	    " \\\n   "
 	    " [--clientprotoport <protocol>/<port>]"
 	    " [--dnskeyondemand]"
+#ifdef XAUTH
+	    " \\\n   "
+	    " [--xauthserver]"
+	    " [--xauthclient]"
+#endif
+#ifdef MODECFG
+	    " [--modecfgserver]"
+	    " [--modecfgclient]"
+#endif
 	    " \\\n   "
 	    " [--updown <updown>]"
 	    " --to"
@@ -80,18 +91,28 @@ help(void)
             " [--cert <path>]"
             " [--groups <access control groups>]"
 	    " [--ca <distinguished name>]"
-	    " [--sendcert]"
-	    " [--sendcerttype number]"
+	    " [--sendcert <yes|ifasked|no]"
+	    " [--certtype number]"
 	    " \\\n   "
 	    " [--ikeport <port-number>]"
 	    " \\\n   "
 	    " [--nexthop <ip-address>]"
 	    " \\\n   "
 	    " [--client <subnet> | --clientwithin <address range>]"
+	    " [--srcip <ip-address>]"
 	    " \\\n   "
 	    " [--clientprotoport <protocol>/<port>]"
-	    " \\\n   "
 	    " [--dnskeyondemand]"
+#ifdef XAUTH
+	    " \\\n   "
+	    " [--xauthserver]"
+	    " [--xauthclient]"
+#endif
+#ifdef MODECFG
+	    " [--modecfgserver]"
+	    " [--modecfgclient]"
+#endif
+	    " \\\n   "
 	    " [--updown <updown>]"
 	    " [--psk]"
 	    " [--rsasig]"
@@ -102,6 +123,8 @@ help(void)
 	    " [--tunnel]"
 	    " [--pfs]"
 	    " \\\n   "
+	    " [--pfsgroup modp1024|modp1536|modp2048|modp3072|modp4096|modp6144|modp8192]"
+	    " \\\n   "
 	    " [--ikelifetime <seconds>]"
 	    " [--ipseclifetime <seconds>]"
 	    " \\\n   "
@@ -120,9 +143,8 @@ help(void)
 	    " [--forceencaps]"
 
 
-#ifdef XAUTH
-	    " [--xauthserver]"
-	    " [--xauthclient]"
+#ifdef MODECFG
+	    " [--modecfgpull]"
 #endif
 	    " \\\n   "
 	    " [--initiateontraffic|--pass|--drop|--reject]"
@@ -176,14 +198,27 @@ help(void)
 	    " [--debug-emitting]"
 	    " \\\n   "
 	    " [--debug-control]"
+	    " [--debug-controlmore]"
 	    " [--debug-klips]"
 	    " [--debug-dns]"
-	    " [--debug-pfkey]"
 	    " \\\n   "
+	    " [--debug-pfkey]"
 	    " [--debug-natt]"
 	    " [--debug-x509]"
+	    " [--debug-dpd]"
 	    " \\\n   "
+	    " [--debug-lifecycle]"
 	    " [--debug-private]"
+	    " \\\n   "
+	    " [--impair-delay-adns-key-answer]"
+	    " [--impair-delay-adns-txt-answer]"
+	    " \\\n   "
+	    " [--impair-bust-mi2]"
+	    " [--impair-bust-mr2]"
+	    " [--impair-sa-fail]"
+	    " \\\n   "
+	    " [--impair-die-oninfo]"
+	    " [--impair-jacob-two-two]"
 	    "\n\n"
 #endif
 	"listen: whack"
@@ -341,7 +376,7 @@ enum option_enums {
     OPT_XAUTHNAME,
     OPT_XAUTHPASS,
 
-#   define OPT_LAST OPT_ASYNC	/* last "normal" option */
+#   define OPT_LAST OPT_DELETECRASH	/* last "normal" option */
 
 /* List options */
 
@@ -940,7 +975,7 @@ main(int argc, char **argv)
 	}
 
 	/* per-class option processing */
-	if (0 <= c && c < OPT_LAST)
+	if (0 <= c && c <= OPT_LAST)
 	{
 	    /* OPT_* options get added opts_seen.
 	     * Reject repeated options (unless later code intervenes).
@@ -1780,7 +1815,7 @@ main(int argc, char **argv)
 
     msg.magic = ((opts_seen & ~(LELEM(OPT_SHUTDOWN) | LELEM(OPT_STATUS)))
 		| lst_seen | cd_seen) != LEMPTY
-	    || msg.whack_options
+	    || msg.whack_options 
 	? WHACK_MAGIC : WHACK_BASIC_MAGIC;
 
     /* send message to Pluto */
