@@ -9,7 +9,9 @@ THREEEIGHT=true
 REF_PUB_OUTPUT=spi1-output.txt
 PRIV_INPUT=../inputs/08-sunrise-sunset-big-sandwich-nic-ping.pcap
 REF_CONSOLE_OUTPUT=test-03-console.txt
+REF26_CONSOLE_OUTPUT=test-03-console26.txt
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-spi-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS pfkey-sanitize.sed"
