@@ -10,6 +10,7 @@ REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS cutout.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-debug-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-setup-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS host-dig-sanitize.sed"
@@ -24,15 +25,18 @@ JAPAN_INIT_SCRIPT=japan-init.sh
 JAPAN_RUN_SCRIPT=japan-run.sh
 JAPAN_FINAL_SCRIPT=japan-final.sh
 REF_JAPAN_CONSOLE_OUTPUT=japan-console.txt
+REF26_JAPAN_CONSOLE_OUTPUT=japan-console.txt
 
 WESTHOST=west
 WEST_INIT_SCRIPT=wavesec-init.sh
 REF_WEST_CONSOLE_OUTPUT=wavesec-console.txt
+REF26_WEST_CONSOLE_OUTPUT=wavesec-console.txt
 
 EASTHOST=east
 EAST_INIT_SCRIPT=east-init.sh
 EAST_FINAL_SCRIPT=east-final.sh
 REF_EAST_CONSOLE_OUTPUT=east-console.txt
+REF26_EAST_CONSOLE_OUTPUT=east-console.txt
 
 ADDITIONAL_HOSTS="sunrise"
 
